wagoe.observability.metrics.schema

Configuration schemas for metrics infrastructure.

This namespace defines Malli schemas for validating metrics configuration, ensuring proper structure and constraints for different metrics providers.

Configuration schemas for metrics infrastructure.

This namespace defines Malli schemas for validating metrics configuration,
ensuring proper structure and constraints for different metrics providers.
raw docstring

AggregationTypeclj

Types of aggregations for metrics.

Types of aggregations for metrics.
sourceraw docstring

ApplicationMetricsConfigclj

Configuration for application-level metrics collection.

Configuration for application-level metrics collection.
sourceraw docstring

BaseMetricsConfigclj

Base metrics configuration shared by all providers.

Base metrics configuration shared by all providers.
sourceraw docstring

BusinessMetricsConfigclj

Configuration for business domain metrics.

Configuration for business domain metrics.
sourceraw docstring

CloudwatchMetricsConfigclj

Configuration for AWS CloudWatch metrics provider.

Configuration for AWS CloudWatch metrics provider.
sourceraw docstring

CustomMetricsConfigclj

Configuration for custom metrics provider.

Configuration for custom metrics provider.
sourceraw docstring

DatadogStatsdConfigclj

Configuration for Datadog StatsD metrics provider.

Configuration for Datadog StatsD metrics provider.
sourceraw docstring

default-application-configclj

Default application metrics configuration.

Default application metrics configuration.
sourceraw docstring

default-business-configclj

Default business metrics configuration.

Default business metrics configuration.
sourceraw docstring

default-datadog-configclj

Default Datadog StatsD metrics configuration.

Default Datadog StatsD metrics configuration.
sourceraw docstring

default-in-memory-configclj

Default in-memory metrics configuration.

Default in-memory metrics configuration.
sourceraw docstring

default-otlp-configclj

Default OTLP metrics configuration (push to a local collector).

Default OTLP metrics configuration (push to a local collector).
sourceraw docstring

default-prometheus-configclj

Default Prometheus metrics configuration.

Default Prometheus metrics configuration.
sourceraw docstring

explain-metrics-configclj

(explain-metrics-config config)

Provides detailed validation errors for metrics configuration.

Provides detailed validation errors for metrics configuration.
sourceraw docstring

explain-system-metrics-configclj

(explain-system-metrics-config config)

Provides detailed validation errors for system metrics configuration.

Provides detailed validation errors for system metrics configuration.
sourceraw docstring

get-schemaclj

(get-schema category schema-name)

Retrieves a schema from the registry by category and name.

Retrieves a schema from the registry by category and name.
sourceraw docstring

InMemoryMetricsConfigclj

Configuration for in-memory metrics provider.

Configuration for in-memory metrics provider.
sourceraw docstring

MetricProviderclj

Supported metrics providers.

Supported metrics providers.
sourceraw docstring

metrics-config-transformerclj

Transforms external configuration to internal format.

Transforms external configuration to internal format.
sourceraw docstring

MetricsConfigclj

Unified metrics configuration schema that validates any provider.

Unified metrics configuration schema that validates any provider.
sourceraw docstring

MetricTypeclj

Types of metrics that can be collected.

Types of metrics that can be collected.
sourceraw docstring

normalize-metrics-configclj

(normalize-metrics-config config)

Normalizes and validates a metrics configuration map.

Normalizes and validates a metrics configuration map.
sourceraw docstring

normalize-system-metrics-configclj

(normalize-system-metrics-config config)

Normalizes and validates a system metrics configuration map.

Normalizes and validates a system metrics configuration map.
sourceraw docstring

OtlpMetricsConfigclj

Configuration for the OpenTelemetry OTLP metrics provider (push to any OTel collector: SigNoz, Grafana, Datadog-via-OTel, …).

Configuration for the OpenTelemetry OTLP metrics provider (push to any OTel
collector: SigNoz, Grafana, Datadog-via-OTel, …).
sourceraw docstring

OtlpProtocolclj

OTLP transport. Only :http/protobuf is bundled (okhttp sender).

OTLP transport. Only `:http/protobuf` is bundled (okhttp sender).
sourceraw docstring

PrometheusMetricsConfigclj

Configuration for Prometheus metrics provider.

Configuration for Prometheus metrics provider.
sourceraw docstring

RetentionConfigclj

Configuration for metrics retention.

Configuration for metrics retention.
sourceraw docstring

SamplingConfigclj

Configuration for metrics sampling.

Configuration for metrics sampling.
sourceraw docstring

schema-registryclj

Registry of all metrics schemas for easy access.

Registry of all metrics schemas for easy access.
sourceraw docstring

StatsdConfigclj

Configuration for generic StatsD metrics provider.

Configuration for generic StatsD metrics provider.
sourceraw docstring

SystemMetricsConfigclj

Complete system metrics configuration.

Complete system metrics configuration.
sourceraw docstring

TaggingConfigclj

Configuration for metric tagging/labeling.

Configuration for metric tagging/labeling.
sourceraw docstring

validate-metrics-configclj

(validate-metrics-config config)

Validates a metrics configuration map.

Validates a metrics configuration map.
sourceraw docstring

validate-system-metrics-configclj

(validate-system-metrics-config config)

Validates a complete system metrics configuration map.

Validates a complete system metrics configuration map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries