wagoe.observability.tracing.shell.adapters.no-op

No-op tracer: satisfies ITracer but records nothing. The default, so feature code can use the tracing port even when tracing is disabled.

No-op tracer: satisfies ITracer but records nothing. The default, so feature
code can use the tracing port even when tracing is disabled.
raw docstring

create-tracerclj

(create-tracer)
(create-tracer _config)
source

create-tracing-componentclj

(create-tracing-component)
(create-tracing-component _config)

The wiring entry point (mirrors the metrics/errors adapters).

The wiring entry point (mirrors the metrics/errors adapters).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries