No-op tracer: satisfies ITracer but records nothing. The default, so feature code can use the tracing port even when tracing is disabled.
No-op tracer: satisfies ITracer but records nothing. The default, so feature code can use the tracing port even when tracing is disabled.
(create-tracing-component)(create-tracing-component _config)The wiring entry point (mirrors the metrics/errors adapters).
The wiring entry point (mirrors the metrics/errors adapters).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |